# ApplePayRequest

Details for a Apple Pay payment method.

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**token** | **{str: (bool, date, datetime, dict, float, int, list, str, none_type)}** | The encrypted (opaque) token that was passed to the &#x60;onpaymentauthorized&#x60; callback by the Apple Pay integration. | 
**method** | **str** | &#x60;applepay&#x60;. | defaults to "applepay"

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


